@@ -9,7 +9,7 @@ CATEGORIES = {
     },
     "history" : {
         "name": _("History"),
-        "icon": load_icon("stock_form-time-field"),
+        "icon": load_icon("document-open-recent"),
     },
     
     # Standard handlers
@@ -19,7 +19,7 @@ CATEGORIES = {
     },
     "emails"    : {    
         "name": _("Emails"),
-        "icon": load_icon("gnome-stock-mail-new"),
+        "icon": load_icon("emblem-mail"),
     },
     "conversations"    : {    
         "name": _("Conversations"),
@@ -31,7 +31,7 @@ CATEGORIES = {
     },
     "people"    : {
         "name": _("People"),
-        "icon": load_icon("user-info"),
+        "icon": load_icon("stock_people"),
     },
     "places"    : {    
         "name": _("Places"),
@@ -47,7 +47,7 @@ CATEGORIES = {
     },
     "websearch"    : {    
         "name": _("Web Search"),
-        "icon": load_icon("gtk-find"),
+        "icon": load_icon("web-search.png"),
     },
     "news"    : {    
         "name": _("News"),
@@ -55,7 +55,18 @@ CATEGORIES = {
     },
     "notes"    : {    
         "name": _("Notes"),
-        "icon": load_icon("stock_notes"),
+        "icon": load_icon("note.png"),
+    },
+    "audio"    : {    
+        "name": _("Audio"),
+        "icon": load_icon("audio-x-generic"),
+    },
+    "video"    : {    
+        "name": _("Video"),
+        "icon": load_icon("video-x-generic"),
+    },
+    "images"    : {    
+        "name": _("Images"),
+        "icon": load_icon("image-x-generic"),
     },
-    
 }
